@@ -53,6 +53,20 @@ define([
         link.rel = "stylesheet";
         link.href = requirejs.toUrl(connectorAddress + vpConst.STYLE_PATH + vpConst.MAIN_CSS_URL);
         document.getElementsByTagName("head")[0].appendChild(link);
+
+        // root variables css
+        link = document.createElement("link");
+        link.type = "text/css";
+        link.rel = "stylesheet";
+        link.href = requirejs.toUrl(connectorAddress + vpConst.STYLE_PATH + 'root.css');
+        document.getElementsByTagName("head")[0].appendChild(link);
+
+        // common component css
+        link = document.createElement("link");
+        link.type = "text/css";
+        link.rel = "stylesheet";
+        link.href = requirejs.toUrl(connectorAddress + vpConst.STYLE_PATH + 'component/common.css');
+        document.getElementsByTagName("head")[0].appendChild(link);
     };
 
     /**
